@@ -2,7 +2,6 @@ use crate::{
     init::{ConfigFormat, Launcher},
     supervise::Properties,
 };
-use log::error;
 use std::{path::PathBuf, time::Duration};
 
 use clap::{Args, Parser, Subcommand};
@@ -63,6 +62,19 @@ pub struct StartArgs {
     /// Configuration file format [yaml, json, toml]
     #[clap(long = "config-type", default_value = "yaml")]
     pub config_type: ConfigFormat,
+
+    #[clap(long = "tls-cert", value_name = "PATH")]
+    pub tls_cert: Option<PathBuf>,
+
+    #[clap(long = "chain-cert", value_name = "PATH")]
+    pub chain_cert: Option<PathBuf>,
+
+    #[clap(long = "tls-key", value_name = "PATH")]
+    pub tls_key: Option<PathBuf>,
+
+    /// Log Level to print [off, trace, debug, error, warn, info]
+    #[clap(short = 'l', long = "log-level", value_name = "LEVEL")]
+    pub log_level: Option<crate::log::LevelFilter>,
 }
 
 impl Into<Launcher> for StartArgs {
@@ -71,11 +83,11 @@ impl Into<Launcher> for StartArgs {
             let res = Launcher::new_from_config(config.to_str().unwrap(), self.config_type);
             match res {
                 Ok(mut res) => {
-                    res.network_id = self.network_id.clone();
+                    res.network_id = Some(self.network_id.clone());
                     res
                 }
                 Err(e) => {
-                    log::error!("{}", e);
+                    eprintln!("{}", e);
                     std::process::exit(1);
                 }
             }
@@ -86,7 +98,11 @@ impl Into<Launcher> for StartArgs {
                 secret: self.secret,
                 token: self.token,
                 wildcard: self.wildcard,
-                network_id: self.network_id,
+                chain_cert: self.chain_cert,
+                tls_cert: self.tls_cert,
+                tls_key: self.tls_key,
+                log_level: self.log_level,
+                network_id: Some(self.network_id),
             }
         }
     }
@@ -99,8 +115,6 @@ pub struct UnsuperviseArgs {
 }
 
 pub async fn init() -> Result<(), anyhow::Error> {
-    crate::utils::init_logger();
-
     let cli = Cli::parse();
 
     let result = match cli.command {
@@ -116,7 +130,7 @@ pub async fn init() -> Result<(), anyhow::Error> {
     };
 
     if result.is_err() {
-        error!("{}", result.unwrap_err())
+        eprintln!("{}", result.unwrap_err())
     }
 
     Ok(())
@@ -124,14 +138,17 @@ pub async fn init() -> Result<(), anyhow::Error> {
 
 async fn start(args: StartArgs) -> Result<(), anyhow::Error> {
     let launcher: Launcher = args.into();
+
     launcher.start().await?;
     Ok(())
 }
 
 fn unsupervise(args: UnsuperviseArgs) -> Result<(), anyhow::Error> {
+    crate::utils::init_logger(Some(tracing::Level::INFO));
     Properties::from(args).uninstall_supervisor()
 }
 
 fn supervise(args: StartArgs) -> Result<(), anyhow::Error> {
+    crate::utils::init_logger(Some(tracing::Level::INFO));
     Properties::from(args).install_supervisor()
 }
