@@ -2,8 +2,10 @@ pub mod addresses;
 pub mod authority;
 pub mod cli;
 pub mod hosts;
+pub mod log;
 pub mod server;
 pub mod supervise;
+pub mod traits;
 pub mod utils;
 
 pub mod init;
