@@ -4,7 +4,8 @@ use std::{
     str::FromStr,
 };
 
-use crate::utils::{domain_or_default, ToHostname};
+use crate::traits::ToHostname;
+use crate::utils::domain_or_default;
 
 #[test]
 fn test_parse_member_name() {
@@ -310,7 +311,10 @@ fn test_parse_hosts() {
                     .unwrap()
                     .first()
                     .unwrap(),
-                &Name::from_str("localhost").unwrap().append_domain(domain),
+                &Name::from_str("localhost")
+                    .unwrap()
+                    .append_domain(domain)
+                    .unwrap(),
                 "{}",
                 path.path().display(),
             );
@@ -321,14 +325,17 @@ fn test_parse_hosts() {
                     .unwrap()
                     .first()
                     .unwrap(),
-                &Name::from_str("localhost").unwrap().append_domain(domain),
+                &Name::from_str("localhost")
+                    .unwrap()
+                    .append_domain(domain)
+                    .unwrap(),
                 "{}",
                 path.path().display(),
             );
 
             let mut accounted = vec!["islay.localdomain", "islay"]
                 .into_iter()
-                .map(|s| Name::from_str(s).unwrap().append_domain(domain));
+                .map(|s| Name::from_str(s).unwrap().append_domain(domain).unwrap());
 
             for name in table
                 .remove(&IpAddr::from_str("127.0.1.1").unwrap())
@@ -359,10 +366,16 @@ fn test_parse_hosts_duplicate() {
     assert!(result.is_some());
     let result = result.unwrap();
 
-    assert!(result.contains(&Name::from_str("hostname1").unwrap().append_domain(&domain)));
+    assert!(result.contains(
+        &Name::from_str("hostname1")
+            .unwrap()
+            .append_domain(&domain)
+            .unwrap()
+    ));
     assert!(result.contains(
         &Name::from_str("hostname2.corp")
             .unwrap()
             .append_domain(&domain)
+            .unwrap()
     ));
 }
