@@ -1,20 +1,26 @@
-use zeronsd::addresses::Calculator;
+use zeronsd::utils::init_logger;
 
 mod service;
 
+#[ctor::ctor]
+fn init() {
+    init_logger(Some(tracing::Level::ERROR));
+}
+
 mod sixplane {
     use std::{net::IpAddr, path::Path, str::FromStr, time::Duration};
 
-    use log::info;
     use rand::prelude::SliceRandom;
+    use tracing::info;
     use trust_dns_resolver::{IntoName, Name};
 
-    use crate::service::{HostsType, Lookup, Service, ServiceConfig, ToIPv6Vec};
-    use zeronsd::{addresses::Calculator, hosts::parse_hosts, utils::init_logger};
+    use crate::service::{
+        resolver::Lookup, to_ip::ToIPv6Vec, utils::HostsType, Service, ServiceConfig,
+    };
+    use zeronsd::{addresses::Calculator, hosts::parse_hosts};
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_single_domain() {
-        init_logger();
         let service = Service::new(ServiceConfig::default().network_filename("6plane-only")).await;
 
         let record = service.member_record();
@@ -23,17 +29,16 @@ mod sixplane {
         let mut listen_ips = service.listen_ips.clone();
         listen_ips.sort();
 
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             let mut ips = service.lookup_aaaa(record.clone()).await;
             ips.sort();
 
-            assert_eq!(ips.sort(), listen_ips.clone().to_ipv6_vec().sort());
+            assert_eq!(ips, listen_ips.clone().to_ipv6_vec());
         }
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_single_domain_named() {
-        init_logger();
         let update_interval = Duration::new(2, 0);
         let service = Service::new(
             ServiceConfig::default()
@@ -53,7 +58,7 @@ mod sixplane {
             let mut listen_ips = service.listen_ips.clone();
             listen_ips.sort();
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let mut ips = service.lookup_aaaa(record.clone()).await;
                 ips.sort();
                 assert_eq!(ips, listen_ips.clone().to_ipv6_vec());
@@ -63,7 +68,6 @@ mod sixplane {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_multi_domain_hosts_file() {
-        init_logger();
         let service = Service::new(
             ServiceConfig::default()
                 .hosts(HostsType::Fixture("basic-ipv6"))
@@ -87,7 +91,7 @@ mod sixplane {
         hosts_map.insert(ip, vec![record.clone().into_name().unwrap()]);
 
         let mut hosts = hosts_map.values().flatten().collect::<Vec<&Name>>();
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             hosts.shuffle(&mut rand::thread_rng());
             let host = *hosts.first().unwrap();
             let ip = service.lookup_aaaa(host.to_string()).await;
@@ -100,7 +104,6 @@ mod sixplane {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_wildcard_central() {
-        init_logger();
         let service = Service::new(
             ServiceConfig::default()
                 .update_interval(Some(Duration::new(5, 0)))
@@ -137,6 +140,7 @@ mod sixplane {
                 let lookup = Name::from_str(&host)
                     .unwrap()
                     .append_domain(&Name::from_str(&rec).unwrap())
+                    .unwrap()
                     .to_string();
                 assert_eq!(
                     service.lookup_aaaa(lookup).await.first().unwrap(),
@@ -150,16 +154,20 @@ mod sixplane {
 mod rfc4193 {
     use std::{net::IpAddr, path::Path, str::FromStr, time::Duration};
 
-    use log::info;
     use rand::{prelude::SliceRandom, thread_rng};
+    use tracing::info;
     use trust_dns_resolver::{IntoName, Name};
+    use zeronsd::{addresses::Calculator, hosts::parse_hosts};
 
-    use crate::service::{HostsType, Lookup, Service, ServiceConfig, ToIPv6Vec, ToPTRVec};
-    use zeronsd::{addresses::Calculator, hosts::parse_hosts, utils::init_logger};
+    use crate::service::{
+        resolver::Lookup,
+        to_ip::{ToIPv6Vec, ToPTRVec},
+        utils::HostsType,
+        Service, ServiceConfig,
+    };
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_single_domain() {
-        init_logger();
         let service = Service::new(ServiceConfig::default().network_filename("rfc4193-only")).await;
 
         let record = service.member_record();
@@ -168,11 +176,11 @@ mod rfc4193 {
         let mut listen_ips = service.listen_ips.clone();
         listen_ips.sort();
 
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             let mut ips = service.lookup_aaaa(record.clone()).await;
             ips.sort();
 
-            assert_eq!(ips.sort(), listen_ips.clone().to_ipv6_vec().sort());
+            assert_eq!(ips, listen_ips.clone().to_ipv6_vec());
         }
 
         let ptr_records: Vec<String> = service
@@ -185,7 +193,7 @@ mod rfc4193 {
         for ptr_record in ptr_records.clone() {
             info!("Looking up {}", ptr_record);
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let service = service.clone();
                 assert_eq!(
                     service
@@ -200,13 +208,13 @@ mod rfc4193 {
 
         info!("Interleaved lookups of PTR and AAAA records");
 
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             // randomly switch order
             if rand::random::<bool>() {
-                assert_eq!(
-                    service.lookup_aaaa(record.clone()).await.sort(),
-                    listen_ips.clone().to_ipv6_vec().sort()
-                );
+                let mut ips = service.lookup_aaaa(record.clone()).await;
+                ips.sort();
+
+                assert_eq!(ips, listen_ips.clone().to_ipv6_vec(),);
 
                 assert_eq!(
                     service
@@ -228,17 +236,15 @@ mod rfc4193 {
                     &record.to_string()
                 );
 
-                assert_eq!(
-                    service.lookup_aaaa(record.clone()).await.sort(),
-                    listen_ips.clone().to_ipv6_vec().sort()
-                );
+                let mut ips = service.lookup_aaaa(record.clone()).await;
+                ips.sort();
+                assert_eq!(ips, listen_ips.clone().to_ipv6_vec());
             }
         }
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_single_domain_named() {
-        init_logger();
         let update_interval = Duration::new(2, 0);
         let service = Service::new(
             ServiceConfig::default()
@@ -259,7 +265,7 @@ mod rfc4193 {
             let mut listen_ips = service.listen_ips.clone();
             listen_ips.sort();
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let mut ips = service.lookup_aaaa(record.clone()).await;
                 ips.sort();
                 assert_eq!(ips, listen_ips.clone().to_ipv6_vec());
@@ -271,7 +277,7 @@ mod rfc4193 {
         for ptr_record in ptr_records {
             info!("Looking up {}", ptr_record);
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let service = service.clone();
                 assert_eq!(
                     service
@@ -287,7 +293,6 @@ mod rfc4193 {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_multi_domain_hosts_file() {
-        init_logger();
         let service = Service::new(
             ServiceConfig::default()
                 .hosts(HostsType::Fixture("basic-ipv6"))
@@ -311,7 +316,7 @@ mod rfc4193 {
         hosts_map.insert(ip, vec![record.clone().into_name().unwrap()]);
 
         let mut hosts = hosts_map.values().flatten().collect::<Vec<&Name>>();
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             hosts.shuffle(&mut rand::thread_rng());
             let host = *hosts.first().unwrap();
             let ip = service.lookup_aaaa(host.to_string()).await;
@@ -324,7 +329,6 @@ mod rfc4193 {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_wildcard_central() {
-        init_logger();
         let service = Service::new(
             ServiceConfig::default()
                 .update_interval(Some(Duration::new(5, 0)))
@@ -361,6 +365,7 @@ mod rfc4193 {
                 let lookup = Name::from_str(&host)
                     .unwrap()
                     .append_domain(&Name::from_str(&rec).unwrap())
+                    .unwrap()
                     .to_string();
                 assert_eq!(
                     service.lookup_aaaa(lookup).await.first().unwrap(),
@@ -374,17 +379,18 @@ mod rfc4193 {
 mod ipv4 {
     use std::time::Duration;
 
-    use log::info;
     use std::str::FromStr;
+    use tracing::info;
     use trust_dns_resolver::Name;
 
-    use zeronsd::utils::init_logger;
-
-    use crate::service::{Lookup, Service, ServiceConfig, ToIPv4Vec, ToPTRVec};
+    use crate::service::{
+        resolver::Lookup,
+        to_ip::{ToIPv4Vec, ToPTRVec},
+        Service, ServiceConfig,
+    };
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_wildcard_central() {
-        init_logger();
         let service = Service::new(
             ServiceConfig::default()
                 .update_interval(Some(Duration::new(5, 0)))
@@ -420,6 +426,7 @@ mod ipv4 {
                 let lookup = Name::from_str(&host)
                     .unwrap()
                     .append_domain(&Name::from_str(&rec).unwrap())
+                    .unwrap()
                     .to_string();
                 assert_eq!(
                     service.lookup_a(lookup).await.first().unwrap(),
@@ -433,7 +440,6 @@ mod ipv4 {
     async fn test_battery_single_domain() {
         use rand::{seq::SliceRandom, thread_rng};
 
-        init_logger();
         let service = Service::new(ServiceConfig::default().ips(Some(vec![
             "172.16.240.2",
             "172.16.240.3",
@@ -447,11 +453,11 @@ mod ipv4 {
         let mut listen_ips = service.listen_ips.clone();
         listen_ips.sort();
 
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             let mut ips = service.lookup_a(record.clone()).await;
             ips.sort();
 
-            assert_eq!(ips.sort(), listen_ips.clone().to_ipv4_vec().sort());
+            assert_eq!(ips, listen_ips.clone().to_ipv4_vec());
         }
 
         let ptr_records: Vec<String> = service
@@ -464,7 +470,7 @@ mod ipv4 {
         for ptr_record in ptr_records.clone() {
             info!("Looking up {}", ptr_record);
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let service = service.clone();
                 assert_eq!(
                     service
@@ -479,13 +485,12 @@ mod ipv4 {
 
         info!("Interleaved lookups of PTR and A records");
 
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             // randomly switch order
             if rand::random::<bool>() {
-                assert_eq!(
-                    service.lookup_a(record.clone()).await.sort(),
-                    listen_ips.clone().to_ipv4_vec().sort()
-                );
+                let mut ips = service.lookup_a(record.clone()).await;
+                ips.sort();
+                assert_eq!(ips, listen_ips.clone().to_ipv4_vec());
 
                 assert_eq!(
                     service
@@ -507,17 +512,15 @@ mod ipv4 {
                     &record.to_string()
                 );
 
-                assert_eq!(
-                    service.lookup_a(record.clone()).await.sort(),
-                    listen_ips.clone().to_ipv4_vec().sort()
-                );
+                let mut ips = service.lookup_a(record.clone()).await;
+                ips.sort();
+                assert_eq!(ips, listen_ips.clone().to_ipv4_vec());
             }
         }
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_single_domain_named() {
-        init_logger();
         let update_interval = Duration::new(2, 0);
         let service = Service::new(
             ServiceConfig::default()
@@ -538,7 +541,7 @@ mod ipv4 {
             let mut listen_ips = service.listen_ips.clone();
             listen_ips.sort();
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let mut ips = service.lookup_a(record.clone()).await;
                 ips.sort();
                 assert_eq!(ips, listen_ips.clone().to_ipv4_vec());
@@ -550,7 +553,7 @@ mod ipv4 {
         for ptr_record in ptr_records {
             info!("Looking up {}", ptr_record);
 
-            for _ in 0..10000 {
+            for _ in 0..1000 {
                 let service = service.clone();
                 assert_eq!(
                     service
@@ -566,16 +569,13 @@ mod ipv4 {
 }
 
 mod all {
-    use log::info;
     use rand::prelude::SliceRandom;
+    use tracing::info;
     use trust_dns_resolver::{IntoName, Name};
 
-    use zeronsd::{
-        hosts::parse_hosts,
-        utils::{init_logger, TEST_HOSTS_DIR},
-    };
+    use zeronsd::{addresses::Calculator, hosts::parse_hosts, utils::TEST_HOSTS_DIR};
 
-    use crate::service::{HostsType, Lookup, Service, ServiceConfig};
+    use crate::service::{resolver::Lookup, utils::HostsType, Service, ServiceConfig};
 
     use std::{
         net::{IpAddr, Ipv4Addr, Ipv6Addr},
@@ -587,7 +587,6 @@ mod all {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_battery_multi_domain_hosts_file() {
-        init_logger();
         let ips = vec!["172.16.240.2", "172.16.240.3", "172.16.240.4"];
         let service = Service::new(
             ServiceConfig::default()
@@ -614,7 +613,7 @@ mod all {
         }
 
         let mut hosts = hosts_map.values().flatten().collect::<Vec<&Name>>();
-        for _ in 0..10000 {
+        for _ in 0..1000 {
             hosts.shuffle(&mut rand::thread_rng());
             let host = *hosts.first().unwrap();
             let ips = service.lookup_a(host.to_string()).await;
@@ -627,7 +626,6 @@ mod all {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_hosts_file_reloading() {
-        init_logger();
         let hosts_path = "/tmp/zeronsd-test-hosts";
         std::fs::write(hosts_path, "127.0.0.2 islay\n::2 islay\n").unwrap();
         let service = Service::new(
@@ -676,64 +674,81 @@ mod all {
             &Ipv6Addr::from_str("::3").unwrap()
         );
     }
-}
 
-#[tokio::test(flavor = "multi_thread")]
-async fn test_get_listen_ip() -> Result<(), anyhow::Error> {
-    use service::*;
-    use zeronsd::utils::*;
+    #[tokio::test(flavor = "multi_thread")]
+    async fn test_get_listen_ip() -> Result<(), anyhow::Error> {
+        use crate::service::{context::TestContext, network::TestNetwork};
+        use zeronsd::utils::*;
 
-    init_logger();
-
-    let tn = TestNetwork::new("basic-ipv4", &mut TestContext::default().await)
-        .await
-        .unwrap();
-
-    let listen_ips = get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap()).await?;
-
-    eprintln!("My listen IP is {}", listen_ips.first().unwrap());
-    assert_ne!(*listen_ips.first().unwrap(), String::from(""));
-
-    drop(tn);
-
-    // see testdata/networks/basic-ipv4.json
-    let mut ips = vec!["172.16.240.2", "172.16.240.3", "172.16.240.4"];
-    let tn =
-        TestNetwork::new_multi_ip("basic-ipv4", &mut TestContext::default().await, ips.clone())
+        let tn = TestNetwork::new("basic-ipv4", &mut TestContext::default().await)
             .await
             .unwrap();
 
-    let mut listen_ips =
-        get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap()).await?;
+        let listen_ips =
+            get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap()).await?;
 
-    assert_eq!(listen_ips.sort(), ips.sort());
-    eprintln!("My listen IPs are {}", listen_ips.join(", "));
+        eprintln!("My listen IP is {}", listen_ips.first().unwrap());
+        assert_ne!(*listen_ips.first().unwrap(), String::from(""));
 
-    let tn = TestNetwork::new("rfc4193-only", &mut TestContext::default().await)
-        .await
-        .unwrap();
+        drop(tn);
 
-    let mut listen_ips =
-        get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap()).await?;
+        // see testdata/networks/basic-ipv4.json
+        let mut ips = vec!["172.16.240.2", "172.16.240.3", "172.16.240.4"];
+        let tn =
+            TestNetwork::new_multi_ip("basic-ipv4", &mut TestContext::default().await, ips.clone())
+                .await
+                .unwrap();
+        ips.sort();
 
-    let mut ips = vec![tn.member().clone().rfc4193()?.ip().to_string()];
+        let mut listen_ips: Vec<String> =
+            get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap())
+                .await?
+                .iter()
+                .map(|x| parse_ip_from_cidr(x.clone()).to_string())
+                .collect();
+        listen_ips.sort();
 
-    assert_eq!(listen_ips.sort(), ips.sort());
-    eprintln!("My listen IPs are {}", listen_ips.join(", "));
+        assert_eq!(listen_ips, ips);
+        eprintln!("My listen IPs are {}", listen_ips.join(", "));
 
-    drop(tn);
+        let tn = TestNetwork::new("rfc4193-only", &mut TestContext::default().await)
+            .await
+            .unwrap();
 
-    let tn = TestNetwork::new("6plane-only", &mut TestContext::default().await)
-        .await
-        .unwrap();
+        let mut listen_ips: Vec<String> =
+            get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap())
+                .await?
+                .iter()
+                .map(|x| parse_ip_from_cidr(x.clone()).to_string())
+                .collect();
+        listen_ips.sort();
 
-    let mut listen_ips =
-        get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap()).await?;
+        let mut ips = vec![tn.member().clone().rfc4193()?.ip().to_string()];
+        ips.sort();
 
-    let mut ips = vec![tn.member().clone().sixplane()?.ip().to_string()];
+        assert_eq!(listen_ips, ips);
+        eprintln!("My listen IPs are {}", listen_ips.join(", "));
 
-    assert_eq!(listen_ips.sort(), ips.sort());
-    eprintln!("My listen IPs are {}", listen_ips.join(", "));
+        drop(tn);
 
-    Ok(())
+        let tn = TestNetwork::new("6plane-only", &mut TestContext::default().await)
+            .await
+            .unwrap();
+
+        let mut listen_ips: Vec<String> =
+            get_listen_ips(&authtoken_path(None), &tn.network.clone().id.unwrap())
+                .await?
+                .iter()
+                .map(|x| parse_ip_from_cidr(x.clone()).to_string())
+                .collect();
+        listen_ips.sort();
+
+        let mut ips = vec![tn.member().clone().sixplane()?.ip().to_string()];
+        ips.sort();
+
+        assert_eq!(listen_ips, ips);
+        eprintln!("My listen IPs are {}", listen_ips.join(", "));
+
+        Ok(())
+    }
 }
